@@ -1,7 +1,7 @@
 package DBIx::Simple::Class::Schema;
 use strict;
 use warnings;
-use 5.10.1;
+use 5.010001;
 use Carp;
 use Data::Dumper;
 use parent 'DBIx::Simple::Class';
@@ -118,7 +118,7 @@ sub _generate_CODE {
 
   push @{$schemas->{$namespace}{code}}, <<"BASE_CLASS";
 package $namespace; #The schema/base class
-use 5.10.1;
+use 5.010001;
 use strict;
 use warnings;
 use utf8;
@@ -137,11 +137,8 @@ sub dbix {
 }
 
 1;
-$/__END__$/$/=pod$/$/=encoding utf8$/$/=head1 NAME
-
-$namespace - the base schema class.
-
-=head1 DESCRIPTION
+$/__END__$/$/=pod$/$/=encoding utf8$/$/=head1 NAME$/$/$namespace - the base schema class.
+$/=head1 DESCRIPTION
 
 This is the base class for using table records as plain Perl objects.
 The subclassses are:$/$/=over
@@ -158,7 +155,7 @@ BASE_CLASS
     my $name_description = "A class for $t->{TABLE_TYPE} $t->{TABLE_NAME} in schema $t->{TABLE_SCHEM}";
     $schemas->{$namespace}{code}[0] .=qq|$/=item L<$package> - $name_description$/|;
     push @{$schemas->{$namespace}{code}}, qq|package $package; #A table/row class
-use 5.10.1;
+use 5.010001;
 use strict;
 use warnings;
 use utf8;
@@ -179,9 +176,7 @@ __PACKAGE__->QUOTE_IDENTIFIERS($t->{QUOTE_IDENTIFIERS});
 #__PACKAGE__->BUILD;#build accessors during load
 
 1;
-| . qq|$/__END__$/$/=pod$/$/=encoding utf8$/$/=head1 NAME
-
-$name_description
+| . qq|$/__END__$/$/=pod$/$/=encoding utf8$/$/=head1 NAME$/$/$name_description
 
 | . qq|=head1 SYNOPSIS$/$/=head1 DESCRIPTION$/$/=head1 COLUMNS$/
 Each column from table C<$t->{TABLE_NAME}> has an accessor method in this class.
